@@ -40,13 +40,14 @@ class BootStyle(ttk.Style):
         self.themes = {}
         self.load_themes()
         self.settings = None
+        self.colors = None
 
     def load_themes(self):
         """Load all ttkbootstrap defined themes"""
         json_data = importlib.resources.read_text('ttkbootstrap', 'themes.json')
         settings = json.loads(json_data)
         for theme in settings['themes']:
-            if theme not in self.theme_names():
+            if theme['name'] not in self.theme_names():
                 settings = ThemeSettings(
                     name=theme['name'],
                     type=theme['type'],
@@ -67,6 +68,7 @@ class BootStyle(ttk.Style):
             current_theme = self.themes.get(themename)
             current_theme.styler_tk.apply_style()
             self.settings = current_theme.settings
+            self.colors = current_theme.settings.color
         except AttributeError:
             pass
 
@@ -75,11 +77,6 @@ class BootStyle(ttk.Style):
         # "ttk::style theme use" in order to change theme.
         self.tk.call("ttk::setTheme", themename)
 
-    def theme_names(self):
-        """Return a sorted list of available themes"""
-        return sorted(super().theme_names())
-
-
 class ThemeSettings:
     """Settings for a ttkbootstrap theme.
 
